namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Multibuttonentry::editable_get() const
{
   Eina_Bool __return_value =  ::elm_obj_multibuttonentry_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::elm_obj_multibuttonentry_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
inline ::efl::eolian::return_traits<bool>::type Multibuttonentry::expanded_get() const
{
   Eina_Bool __return_value =  ::elm_obj_multibuttonentry_expanded_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::expanded_set( ::efl::eolian::in_traits<bool>::type expanded) const
{
    ::elm_obj_multibuttonentry_expanded_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(expanded));
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::format_function_set( ::efl::eolian::in_traits<Elm_Multibuttonentry_Format_Cb>::type format_function,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::elm_obj_multibuttonentry_format_function_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Format_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Format_Cb>::type>(format_function)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Multibuttonentry::items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_multibuttonentry_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::first_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_first_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::last_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_last_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Multibuttonentry::entry_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_multibuttonentry_entry_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::selected_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_selected_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_prepend( ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_prepend(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::clear() const
{
    ::elm_obj_multibuttonentry_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_remove( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_insert_before( ::efl::eolian::in_traits< ::elm::widget::Item>::type before,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_insert_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(before)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_prepend( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_prepend(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_append( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_insert_after( ::efl::eolian::in_traits< ::elm::widget::Item>::type after,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_insert_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(after)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace elm { 
inline ::efl::eolian::return_traits<bool>::type Multibuttonentry::editable_get() const
{
   Eina_Bool __return_value =  ::elm_obj_multibuttonentry_editable_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::editable_set( ::efl::eolian::in_traits<bool>::type editable) const
{
    ::elm_obj_multibuttonentry_editable_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(editable));
}
inline ::efl::eolian::return_traits<bool>::type Multibuttonentry::expanded_get() const
{
   Eina_Bool __return_value =  ::elm_obj_multibuttonentry_expanded_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::expanded_set( ::efl::eolian::in_traits<bool>::type expanded) const
{
    ::elm_obj_multibuttonentry_expanded_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Eina_Bool,  ::efl::eolian::in_traits<bool>::type>(expanded));
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::format_function_set( ::efl::eolian::in_traits<Elm_Multibuttonentry_Format_Cb>::type format_function,  ::efl::eolian::in_traits<void const*>::type data) const
{
    ::elm_obj_multibuttonentry_format_function_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Format_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Format_Cb>::type>(format_function)
      ,  ::efl::eolian::convert_to_c<const void *,  ::efl::eolian::in_traits<void const*>::type>(data));
}
inline ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type Multibuttonentry::items_get() const
{
   const Eina_List * __return_value =  ::elm_obj_multibuttonentry_items_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<  ::efl::eina::range_list< ::elm::widget::Item>>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::first_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_first_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::last_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_last_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::canvas::Object>::type Multibuttonentry::entry_get() const
{
    ::Efl_Canvas_Object* __return_value =  ::elm_obj_multibuttonentry_entry_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::canvas::Object>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::selected_item_get() const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_selected_item_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_prepend( ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_prepend(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::clear() const
{
    ::elm_obj_multibuttonentry_clear(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_remove( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_insert_before( ::efl::eolian::in_traits< ::elm::widget::Item>::type before,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_insert_before(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(before)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_append( ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_prepend( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_prepend(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits<void>::type Multibuttonentry::item_filter_append( ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::elm_obj_multibuttonentry_item_filter_append(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<Elm_Multibuttonentry_Item_Filter_Cb,  ::efl::eolian::in_traits<Elm_Multibuttonentry_Item_Filter_Cb>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
}
inline ::efl::eolian::return_traits< ::elm::widget::Item>::type Multibuttonentry::item_insert_after( ::efl::eolian::in_traits< ::elm::widget::Item>::type after,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type label,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type func,  ::efl::eolian::in_traits<void*>::type data) const
{
    ::Elm_Widget_Item* __return_value =  ::elm_obj_multibuttonentry_item_insert_after(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Elm_Widget_Item*,  ::efl::eolian::in_traits< ::elm::widget::Item>::type>(after)
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(label)
      ,  ::efl::eolian::convert_to_c<Evas_Smart_Cb,  ::efl::eolian::in_traits< ::efl::eina::optional<Evas_Smart_Cb>>::type>(func)
      ,  ::efl::eolian::convert_to_c<void *,  ::efl::eolian::in_traits<void*>::type>(data));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::elm::widget::Item>::type>(__return_value);
}
inline elm::Multibuttonentry::operator ::elm::Multibuttonentry() const { return *static_cast< ::elm::Multibuttonentry const*>(static_cast<void const*>(this)); }
inline elm::Multibuttonentry::operator ::elm::Multibuttonentry&() { return *static_cast< ::elm::Multibuttonentry*>(static_cast<void*>(this)); }
inline elm::Multibuttonentry::operator ::elm::Multibuttonentry const&() const { return *static_cast< ::elm::Multibuttonentry const*>(static_cast<void const*>(this)); }
} }

